@@ -1,7 +1,7 @@
 from datetime import timedelta
 import json
+import pkgutil
 import math
-import os
 from jwt import (
     JWT,
     jwk_from_pem,
@@ -271,17 +271,8 @@ class Client():
         metadata_response = self.get("https://www.googleapis.com/analytics/v3/metadata/{reportType}/columns".format(reportType="ga"))
         return metadata_response.json()
 
-    def get_raw_cubes(self):
-        try:
-            cubes_response = self.get("https://ga-dev-tools.appspot.com/ga_cubes.json")
-            cubes_response.raise_for_status()
-            cubes_json = cubes_response.json()
-        except Exception as ex:
-            LOGGER.warning("Error fetching raw cubes, falling back to local copy. Exception message: %s", ex)
-            local_cubes_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "ga_cubes.json")
-            with open(local_cubes_path, "r") as f:
-                cubes_json = json.load(f)
-        return cubes_json
+    def get_raw_cubes(self): # pylint: disable=no-self-use
+        return json.loads(pkgutil.get_data(__package__, "ga_cubes.json"))
 
     def get_account_summaries_for_token(self):
         """
